\name{spdest}
\alias{spdest}
\alias{spdest.beta2theta}
\alias{spdest.theta2beta}
\alias{spdest.nnls}
\alias{spdest.fastw}
\alias{spdest.recent}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{spdest}
\description{
  Nonparametric estimation of State-Price-Densities from observed European Call- and Put- option  prices.
}
\usage{
spdest(price, rfr = 0, mat = 1, ttime = NULL, fast = FALSE, fast.type = "brab", nrec = 2, iter = 2)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{price}{ Matrix (n x 3) \code{price} 1st column contains the strike price, 2nd column the corresponding option price and 3 column is (binary) indicator of put option price.}
  \item{rfr}{ scalar, \code{rfr} is the risk free interest rate }
  \item{mat}{ scalar, \code{mat} is the time to maturity }
  \item{ttime}{ vector (of length n) \code{ttime} of the transaction times }
  \item{fast}{ set \code{fast} to TRUE if you want to use faster algorithm }
  \item{fast.type}{ type \code{fast.type} of the fast algorithm ("crab", "brab") }
  \item{nrec}{ scalar, parameter of the fast algorithm, \code{nrec} is number of recent observations within each observed strike price}
  \item{iter}{ scalar, parameter of the fast algorithm, \code{iter} is the number of iterations}
}
\details{
  See Hrdle, W., Hlvka, Z. (2005) ,"Dynamics of state price densities", Discussion Paper 2005-021, SFB 649, Humboldt-Universitt zu Berlin. http://sfb649.wiwi.hu-berlin.de/

  The fast algorithm is described in Hlvka, Z., (2006), "Fast algorithm for nonparametric arbitrage-free SPD estimation", Computational Statistics and Data Analysis, submitted. 
}
\value{
  \item{spd }{SPD estimate in the observed strike prices}
  \item{var.spd }{estimated "pointwise" variances of the SPD estimator}
  \item{fit.call }{fitted call option prices (positive decreasing convex) }
  \item{fit.put }{fitted  put option prices (positive increasing convex) }
  \item{der }{integrated SPD (1st derivative of the observed prices wrt strike price)}
  \item{ci }{confidence limits from nonlinear least squares}
  \item{ci.lm }{confidence limits based on linear model}
  \item{n }{the number of observations used in the calculation (if fast method is used)}
}
\references{Hrdle, W., Hlvka, Z. (2005) ,"Dynamics of state price densities", Discussion Paper 2005-021, SFB 649, Humboldt-Universitt zu Berlin. http://sfb649.wiwi.hu-berlin.de/

Hlvka, Z., (2006), "Fast algorithm for nonparametric arbitrage-free SPD estimation", submitted to Computational Statistics and Data Analysis.
 }
\author{ Zdenek Hlavka, Charles University in Prague, Sokolovska 83, 18675 Praha 8, Czech Republic, hlavka@karlin.mff.cuni.cz}
\note{}

\seealso{ \code{\link{spdest.xd}},\code{\link{spdest.cvr}}}
\examples{
library(MASS)
library(SPDest)

## set the random seed (change it to obtain different simulated values :-)
set.seed(1)

## set the number of observations
npoz=20

## set the true call and put prices and corresponding SPD
true.call=cbind(c(10,20,30,40),c(17.5,9,2.5,2))
true.put=cbind(c(10,20,30,40),c(3,4.5,8,17.5))
true.spd=c(0.15,0.2,0.6,0.05)

x=cbind(rbind(true.call,true.put),c(rep(0,4),rep(1,4)))

## calculate the nr. of replication of each strike and random order of transactions
rep.sim=rmultinom(1,npoz,rep(true.spd/2,2))
x.sim=apply(x,2,rep,times=rep.sim)
xord=order(x.sim[,3],x.sim[,1])
x.sim=x.sim[xord,]

## true covariance matrix for the random errors
temp=spdest.xd(x.sim)
ttime=sqrt(runif(npoz))

## true covariance matrix for the random errors using function spdest.cvr()
true.var=spdest.cvr(ttime,temp$L,temp$xd,nc=npoz-sum(x.sim[,3]),np=sum(x.sim[,3]),CL=TRUE,PT=TRUE)

## generate the correlated random errors
tmp=eigen(true.var)
var12=tmp$vectors\%*\%diag(sqrt(tmp$values))\%*\%t(tmp$vectors)
errors=0.1*var12\%*\%as.matrix(rnorm(npoz))
pr=x.sim
pr[,2]=pr[,2]+errors

## print the matrix used as input for the programme
## 1.column contains the strike prices
## 2.column contains the (random) option prices
## 3.column is the put-call indicator
print(pr)

## run the programme using 3 variants of the algorithm
a.full=spdest(price=pr,ttime=ttime)
a.crab=spdest(price=pr,ttime=ttime,fast=TRUE,fast.type="crab",nrec=2,iter=2)
a.brab=spdest(price=pr,ttime=ttime,fast=TRUE,fast.type="brab",nrec=2,iter=2)

## plot the results
par(mfrow=c(3,1))
plot(pr,col=1,xlab="strike",ylab="price",main=paste("SPD estimate, ",npoz," observations.",sep=""))
lines(a.full$fit.call,col=2)
lines(a.full$fit.put,col=2)
lines(true.call,col=1)
lines(true.put,col=1)
plot(pr,col=1,xlab="strike",ylab="price",main=paste("SPD estimate (CRAB), ",npoz," observations.",sep=""))
lines(a.crab$fit.call,col=2)
lines(a.crab$fit.put,col=2)
lines(true.call,col=1)
lines(true.put,col=1)
plot(pr,col=1,xlab="strike",ylab="price",main=paste("SPD estimate (BRAB), ",npoz," observations.",sep=""))
lines(a.brab$fit.call,col=2)
lines(a.brab$fit.put,col=2)
lines(true.call,col=1)
lines(true.put,col=1)
}
\keyword{ nonparametric }% at least one, from doc/KEYWORDS
\keyword{ regression }% __ONLY ONE__ keyword per line
